realtime - Set of tools for realtime and forcasted data — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- homepage|
- search|
- documentation »

# realtime - Set of tools for realtime and forcasted data

The realtime module fetches realtime data and forecasts from other sites

Authors: Josef Koller

Institution: Los Alamos National Laboratory

Contact: jkoller@lanl.gov

Copyright 2012 Los Alamos National Security, LLC.

## About realtime

bla bla

## Examples

badf asdfasdf asdf

    >>> import spacepy.realtime as rt

`nextForecast`() | Return only the next value
`now`() | Return the current values for the parameters
`forecast`() |

### Navigation

- index
- modules |
- modules |
- homepage|
- search|
- documentation »